/* empty css              */import{B as t,C as l,R as r,D as i,G as m,I as c,J as u,K as C,b as d,H as p,n as f}from"./index-CD7iYaFT.js";const y=l({fluid:{type:Boolean,default:!1},...C(),...u(),...c()},"VContainer"),v=t()({name:"VContainer",props:y(),setup(e,s){let{slots:a}=s;const{rtlClasses:n}=r(),{dimensionStyles:o}=i(e);return m(()=>d(e.tag,{class:f(["v-container",{"v-container--fluid":e.fluid},n.value,e.class]),style:p([o.value,e.style])},a)),{}}});export{v as V};
