import{I as f,_ as v}from"./ProviderDetails.vue_vue_type_script_setup_true_lang-Chq_R5dV.js";import{I}from"./ItemsListing-ByrUsYKd.js";import{d as _,r as m,ae as h,m as b,v as a,a$ as y,q as k,c as w,b as E,h as p,e as n,F as D,o as r}from"./index-CD7iYaFT.js";import"./Toolbar-B7AWyK9d.js";import"./VToolbar-BQejIjUR.js";import"./VBtn-B0XatuYF.js";import"./_plugin-vue_export-helper-DlAUqK2U.js";import"./marquee_text_sync-gz0T_gx6.js";import"./MediaItemThumb-BVMzVj0K.js";import"./VDialog-3VB6G7S5.js";import"./layout-BCm0QQDS.js";import"./Container-ClW3AMEw.js";import"./index-CBho6rsP.js";import"./VContainer-DFqPxZ0T.js";/* empty css              */import"./ListItem-C-HNqEeC.js";import"./Button-BUjpiwEZ.js";import"./NowPlayingBadge.vue_vue_type_style_index_0_lang-Dl2aFjrE.js";import"./VInput-DDFZ8lhb.js";import"./PanelviewItemCompact-DmP5jPAL.js";import"./VSpacer-B8t0Vh55.js";import"./VTextField-CVfOZKc3.js";import"./VInfiniteScroll-DHXPR3PY.js";import"./VRow-DFe5cA7D.js";import"./VVirtualScroll-BREm3RjH.js";import"./VAlert-cuze2JsR.js";const X=_({__name:"PodcastDetails",props:{itemId:{},provider:{}},setup(l){const t=l,i=m(!1),e=m(),d=async function(){e.value=await a.getPodcast(t.itemId,t.provider)};h(()=>t.itemId,o=>{o&&d()},{immediate:!0}),b(()=>{const o=a.subscribe(y.MEDIA_ITEM_UPDATED,s=>{const c=s.data;e.value?.uri==c.uri&&(i.value=!0)});k(o)});const u=async function(o){return await a.getPodcastEpisodes(t.itemId,t.provider)};return(o,s)=>(r(),w(D,null,[E(f,{item:e.value},null,8,["item"]),e.value?(r(),p(I,{key:0,itemtype:"podcastepisodes","parent-item":e.value,"show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!0,"show-refresh-button":!0,"load-items":u,"sort-keys":["position","position_desc","name","duration","duration_desc"],"update-available":i.value,title:o.$t("podcast_episodes"),"allow-key-hooks":!0,path:`podcast.${t.itemId}.${t.provider}`,"restore-state":!0,"no-server-side-sorting":!0},null,8,["parent-item","update-available","title","path"])):n("",!0),e.value?(r(),p(v,{key:1,"item-details":e.value},null,8,["item-details"])):n("",!0)],64))}});export{X as default};
