/* empty css              */import{B as C,C as S,O as b,cq as k,I as N,K as j,cr as i,cs as u}from"./index-CD7iYaFT.js";const V=i.reduce((t,n)=>(t[n]={type:[Boolean,String,Number],default:!1},t),{}),v=i.reduce((t,n)=>{const e="offset"+u(n);return t[e]={type:[String,Number],default:null},t},{}),L=i.reduce((t,n)=>{const e="order"+u(n);return t[e]={type:[String,Number],default:null},t},{}),y={col:Object.keys(V),offset:Object.keys(v),order:Object.keys(L)};function G(t,n,e){let s=t;if(!(e==null||e===!1)){if(n){const l=n.replace(t,"");s+=`-${l}`}return t==="col"&&(s="v-"+s),t==="col"&&(e===""||e===!0)||(s+=`-${e}`),s.toLowerCase()}}const I=["auto","start","end","center","baseline","stretch"],_=S({cols:{type:[Boolean,String,Number],default:!1},...V,offset:{type:[String,Number],default:null},...v,order:{type:[String,Number],default:null},...L,alignSelf:{type:String,default:null,validator:t=>I.includes(t)},...j(),...N()},"VCol"),q=C()({name:"VCol",props:_(),setup(t,n){let{slots:e}=n;const s=b(()=>{const l=[];let a;for(a in y)y[a].forEach(o=>{const c=t[o],g=G(a,o,c);g&&l.push(g)});const r=l.some(o=>o.startsWith("v-col-"));return l.push({"v-col":!r||!t.cols,[`v-col-${t.cols}`]:t.cols,[`offset-${t.offset}`]:t.offset,[`order-${t.order}`]:t.order,[`align-self-${t.alignSelf}`]:t.alignSelf}),l});return()=>k(t.tag,{class:[s.value,t.class],style:t.style},e.default?.())}}),f=["start","end","center"],$=["space-between","space-around","space-evenly"];function d(t,n){return i.reduce((e,s)=>{const l=t+u(s);return e[l]=n(),e},{})}const B=[...f,"baseline","stretch"],h=t=>B.includes(t),w=d("align",()=>({type:String,default:null,validator:h})),R=[...f,...$],P=t=>R.includes(t),E=d("justify",()=>({type:String,default:null,validator:P})),T=[...f,...$,"stretch"],A=t=>T.includes(t),O=d("alignContent",()=>({type:String,default:null,validator:A})),m={align:Object.keys(w),justify:Object.keys(E),alignContent:Object.keys(O)},U={align:"align",justify:"justify",alignContent:"align-content"};function K(t,n,e){let s=U[t];if(e!=null){if(n){const l=n.replace(t,"");s+=`-${l}`}return s+=`-${e}`,s.toLowerCase()}}const M=S({dense:Boolean,noGutters:Boolean,align:{type:String,default:null,validator:h},...w,justify:{type:String,default:null,validator:P},...E,alignContent:{type:String,default:null,validator:A},...O,...j(),...N()},"VRow"),z=C()({name:"VRow",props:M(),setup(t,n){let{slots:e}=n;const s=b(()=>{const l=[];let a;for(a in m)m[a].forEach(r=>{const o=t[r],c=K(a,r,o);c&&l.push(c)});return l.push({"v-row--no-gutters":t.noGutters,"v-row--dense":t.dense,[`align-${t.align}`]:t.align,[`justify-${t.justify}`]:t.justify,[`align-content-${t.alignContent}`]:t.alignContent}),l});return()=>k(t.tag,{class:["v-row",s.value,t.class],style:t.style},e.default?.())}});export{z as V,q as a};
